@@ -150,21 +150,25 @@ as.neuronlist.default<-function(l, df=NULL, AddClassToNeurons=TRUE, ...){
   }
   # treat as neuronlist
   nl2=structure(NextMethod("["), class = class(x))
-  # now handle attributes
-  # first general attributes
-  atts=attributes(x)
-  atts_to_copy=atts[setdiff(names(atts),c("names","dim","dimnames","df"))]
-  atts_to_copy[['names']]=names(nl2)
-  attributes(nl2) <- atts_to_copy
+  # we never want to drop because the result must be a data.frame
+  # even when it only has one column
+  attr(nl2, 'df') = attr(x, 'df')[i, , drop = FALSE]
+  copy_nl_attributes(nl2, x)
+}
+
+# Private function to copy attributes of a neuronlist
+# note that this only deals with non-standard attributes
+# the caller is still responsible for insuring that new has the correct 
+# class, names, df etc
+copy_nl_attributes <- function(new, old, ignoremore=NULL) {
+  oldatts = attributes(old)
+  newatts = attributes(new)
+  ignored_atts=union(names(newatts), c("names", "dim", "dimnames", "df", "class"))
+  ignored_atts=union(ignored_atts, ignoremore)
+  atts_to_copy = oldatts[setdiff(names(oldatts), ignored_atts)]
+  attributes(new) <- c(attributes(new), atts_to_copy)
   # and then specialcase the metadata data.frame
-  df=attr(x,'df')
-  if(!is.null(df)){
-    # we never want to drop because the result must be a data.frame 
-    # even when it only has one column
-    df=df[i, , drop=FALSE]
-  }
-  attr(nl2,'df')=df
-  nl2
+  new
 }
 
 #' @export
@@ -293,7 +297,13 @@ as.data.frame.neuronlist<-function(x, row.names = names(x), optional = FALSE, ..
       warning(length(missing_neurons),
               " rows in data.frame do not have a matching neuron.")
   } else {
-    stop("data.frame rownames do not match neuron names.")
+    if(isTRUE(length(nn)==nrow(value))) {
+      if(base::.row_names_info(value)>0) {
+        # Row names are not automatic but do not match
+        warning("Assuming new data.frame correctly ordered in spite of rownames mismatch!")
+      }
+      rownames(value) <- matching_rows <- nn
+    } else stop("data.frame rownames do not match neuron names.")
   }
   if(!isTRUE(all.equal(rownames(value), matching_rows))) {
     # we need to reorder the rows and/or subset the incoming data.frame
